<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Strings for component 'tool_unsuproles', language 'en', branch 'MOODLE_22_STABLE'
 *
 * @package    tool
 * @subpackage unsuproles
 * @copyright  2010 Petr Skoda {@link http://skodak.org}
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

$string['contextlevel'] = 'Context level';
$string['count'] = 'Count';
$string['confirmdelete'] = 'Do you really want to delete all unsupported role assignments for role "{$a->role}" in context level "{$a->level}"?';
$string['noprolbems'] = 'No unsupported role assignments found.';
$string['pluginname'] = 'Unsupported role assignments';
$string['privacy:metadata'] = 'The Unsupported role assignments plugin does not store any personal data.';
