{{!
    This file is part of Moodle - http://moodle.org/

    Moodle is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Moodle is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Moodle.  If not, see <http://www.gnu.org/licenses/>.
}}
{{!
    @template core_calendar/event_filter

    Filter to select which event types displayed on this page.

    Classes required for JS:
    * none

    Data attributes required for JS:
    * none

    Example context (json):
    {
    }
}}
<div id="event-filter-{{uniqid}}" class="calendar_filters mt-2">
    <ul>
        {{#eventtypes}}
            <li>
                {{> core_calendar/event_filter_key }}
            </li>
        {{/eventtypes}}
    </ul>
</div>
{{#js}}
require(['jquery', 'core_calendar/calendar_filter'], function($, CalendarFilter) {
    CalendarFilter.init($("#event-filter-{{uniqid}}"));
});
{{/js}}
