{{!
    This file is part of Moodle - http://moodle.org/

    Moodle is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Moodle is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Moodle.  If not, see <http://www.gnu.org/licenses/>.
}}
{{!
    @template qbank_comment/comment_modal

    The template that renders the modal window for adding comments to questions.
    * question - The html of the question.
    * comment - The html of the comment.
    * commenstdisabled - If true display the comment disabled notification.

    Example context (json):
    {
        "commentdata": [
            {
                "question": "question html",
                "comment": "comment html",
                "commenstdisabled": "bool"
            }
        ]
    }
}}
{{#versionselection}}
    {{> core_question/question_version_selection }}
{{/versionselection}}
<div class="question-comment-preview">
    {{{question}}}
</div>
<div class="question-comment-view">
    {{{comment}}}
    {{#commenstdisabled}}
        <a class="alert-danger">
            {{#str}} commentdisabled, qbank_comment {{/str}}
        </a>
    {{/commenstdisabled}}
</div>
