{{!
    This file is part of Moodle - http://moodle.org/

    Moodle is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Moodle is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Moodle.  If not, see <http://www.gnu.org/licenses/>.
}}
{{!
    @template gradereport_grader/headercell

    Header cell template

    Example context (json):
    {
        "headerlink": "<a class='gradeitemheader' href='index.php?id=2&amp;sortitemid=2'><img class='icon itemicon' src='http://moodlesite/theme/image.php/boost/assign/1680563323/monologo' alt='Assignment' />Assignment 1</a>",
        "arrow": "<a title='Descending' aria-label='Descending' href='index.php?id=2&amp;sortitemid=2'><i class='icon fa fa-sort-desc fa-fw sorticon' aria-hidden='true'  ></i></a>",
        "singleview": "<div class='action-menu moodle-actionmenu grader' id='action-menu-8' data-enhance='moodle-core-actionmenu'></div>",
        "statusicons": "<div class='grade_icons'><i class='icon fa fa-lock fa-fw text-muted' title='Locked' role='img' aria-label='Locked'></i></div>"
    }
}}
<div class="d-flex flex-column h-100">
    <div class="d-none flex-grow-1 align-items-start" data-collapse="expandbutton">
        {{{collapsedicon}}}
    </div>
    <div class="d-flex" data-collapse="content">
        <div class="d-flex flex-grow-1">
            {{{headerlink}}}
            <div class="mx-2 mt-2">
                {{{arrow}}}
            </div>
        </div>
        <div>
            {{{singleview}}}
        </div>
    </div>
    <div class="d-flex flex-grow-1 align-items-end">
        {{{statusicons}}}
    </div>
</div>
